==> 2.4.11.tar.gz: cloudlog/application/language/finnish/account_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['account_logbook_fields'] = 'Lokin sarakkeiden sisältö';
$lang['account_column1_text'] = 'Sarake 1';
$lang['account_column2_text'] = 'Sarake 2';
$lang['account_column3_text'] = 'Sarake 3';
$lang['account_column4_text'] = 'Sarake 4';
$lang['account_column5_text'] = 'Sarake 5 (vain lokikirjassa)';

$lang['account_create_user_account'] = 'Luo käyttäjätili';
$lang['account_edit_account'] = 'Muokkaa käyttäjätiliä';

$lang['account_account_information'] = 'Account Information';
$lang['account_username'] = 'käyttäjänimi';
$lang['account_email_address'] = 'Email';
$lang['account_password'] = 'Salasana';

$lang['account_roles'] = 'Roolit';
$lang['account_user_role'] = 'Käyttäjän rooli';
$lang['account_word_admin'] = 'Admin';

$lang['account_theme'] = 'Teema';
$lang['account_stylesheet'] = 'Tyylisivu';

$lang['account_personal_information'] = 'Henkilötiedot';
$lang['account_first_name'] = 'Etunimi';
$lang['account_last_name'] = 'Sukunimi';
$lang['account_callsign'] = 'Radioamatöörikutsu';
$lang['account_gridsquare'] = 'Gridsquare';

$lang['account_cloudlog_preferences'] = 'Cloudlog Asetukset';
$lang['account_timezone'] = 'Aikavyöhyke';
$lang['account_date_format'] = 'Päivämäärämuoto';
$lang['account_measurement_preferences'] = 'Mittayksikkömuoto';
$lang['account_select_how_you_would_like_dates_shown_when_logged_into_your_account'] = 'Valitse, miten haluat päivämäärät näkyvän, kun olet kirjautunut tilillesi.';
$lang['account_choose_which_unit_distances_will_be_shown_in'] = 'Valitse, mitä mittayksikkömuotoa käytetään';
$lang['account_cloudlog_language'] = 'Cloudlog Language';
$lang['account_choose_cloudlog_language'] = 'Choose Cloudlog language.';

$lang['account_main_menu'] = 'Main Menu';
$lang['account_show_notes_in_the_main_menu'] = 'Näytä "Muistio" päävalikossa.';

$lang['account_gridsquare_and_location_autocomplete'] = 'Gridsquare and Location Autocomplete';
$lang['account_location_auto_lookup'] = 'Location auto lookup.';
$lang['account_if_set_gridsquare_is_fetched_based_on_location_name'] = 'If set, gridsquare is fetched based on location name.';
$lang['account_sota_auto_lookup_gridsquare_and_name_for_summit'] = 'SOTA auto lookup gridsquare and name for summit.';
$lang['account_wwff_auto_lookup_gridsquare_and_name_for_reference'] = 'WWFF auto lookup gridsquare and name for reference.';
$lang['account_pota_auto_lookup_gridsquare_and_name_for_park'] = 'POTA auto lookup gridsquare and name for park.';
$lang['account_if_set_name_and_gridsquare_is_fetched_from_the_api_and_filled_in_location_and_locator'] = 'If set, name and gridsquare is fetched from the API and filled in location and locator.';

$lang['account_previous_qsl_type'] = 'Previous QSL Type';
$lang['account_select_the_type_of_qsl_to_show_in_the_previous_qsos_section'] = 'Select the type of QSL to show in the previous QSOs section.';

$lang['account_qrzcom_hamqthcom_images'] = 'qrz.com/hamqth.com Kuvat';
$lang['account_show_profile_picture_of_qso_partner_from_qrzcom_hamqthcom_profile_in_the_log_qso_section'] = 'Näytä kusokumppanin profiilikuva qrz.com/hamqth.com -profiilista lokin QSO:n kirjausikkunassa.';
$lang['account_please_set_your_qrzcom_hamqthcom_credentials_in_the_general_config_file'] = 'Anna qrz.com/hamqth.com tunnustiedot in the general config file.';

$lang['account_amsat_status_upload'] = 'AMSAT Status Upload';
$lang['account_upload_status_of_sat_qsos_to'] = 'Upload status of SAT QSOs to';

$lang['account_logbook_of_the_world'] = 'Logbook of the World';
$lang['account_logbook_of_the_world_lotw_username'] = 'Logbook of The World (LoTW) Käyttäjänimi';
$lang['account_logbook_of_the_world_lotw_password'] = 'Logbook of The World (LoTW) Salasana';
$lang['account_leave_blank_to_keep_existing_password'] = 'Jätä tyhjäksi säilyttääksesi tietokannan nykyisen salasanan';

$lang['account_clublog'] = 'Club Log';
$lang['account_clublog_email_callsign'] = 'Club Log Sähköposti/Kutsu';
$lang['account_clublog_password'] = 'Club Log Salasana';
$lang['account_the_email_or_callsign_you_use_to_login_to_club_log'] = 'Sähköposti tai kutsu, jota käytät kirjautuessasi Club Log:iin';

$lang['account_eqsl'] = 'eQSL';
$lang['account_eqslcc_username'] = 'eQSL.cc Käyttäjänimi';
$lang['account_eqslcc_password'] = 'eQSL.cc Salasana';

$lang['account_save_account_changes'] = 'Tallenna käyttäjätilin muutokset';
$lang['account_create_account'] = 'Luo käyttäjätili';

$lang['account_delete_user_account'] = 'Poista käyttäjätili';
$lang['account_are_you_sure_you_want_to_delete_the_user_account'] = 'Oletko varma, että haluat poistaa käyttäjätilin';
$lang['account_yes_delete_this_user'] = 'Kyllä, poista tämä käyttäjätili';
$lang['account_no_do_not_delete_this_user'] = 'En, älä poista tätä käyttäjätiliä';

$lang['account_forgot_password'] = 'Salasana unohtunut?';
$lang['account_you_can_reset_your_password_here'] = 'Voit resetoida salasanasi tästä';
$lang['account_reset_password'] = 'Resetoi salasana';
$lang['account_the_email_field_is_required'] = 'Sähköpostikenttä on pakollinen';
$lang['account_confirm_password'] = 'Vahvista salasana';

$lang['account_forgot_your_password'] = 'Salasana unohtunut?';

$lang['account_login_to_cloudlog'] = 'Kirjaudu Cloudlogiin';
$lang['account_login'] = 'Kirjaudu';

$lang['account_mastodon'] = 'Mastodonserver';
$lang['account_user_mastodon'] = 'URL of Mastodonserver';
$lang['account_user_mastodon_hint'] = "Main URL of your Mastodon server, e.g. <a href='https://radiosocial.de/' target='_blank'>https://radiosocial.de";

$lang['account_default_band_settings'] = 'Settings for Default Band and Confirmation';
$lang['account_gridmap_default_band'] = 'Oletusbandi';
$lang['account_qsl_settings'] = 'Default QSL-Methods';

$lang['account_winkeyer'] = 'Winkeyer';
$lang['account_winkeyer_hint'] = "Winkeyer support in Cloudlog is very experimental read the wiki first at <a href='https://github.com/magicbug/Cloudlog/wiki/Winkey' target='_blank'>https://github.com/magicbug/Cloudlog/wiki/Winkey</a> before enabling.";
$lang['account_winkeyer_enabled'] = "Winkeyer Features Enabled";

==> 2.5.2.tar.gz: cloudlog/application/language/finnish/account_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['account_logbook_fields'] = 'Lokin sarakkeiden sisältö';
$lang['account_column1_text'] = 'Sarake 1';
$lang['account_column2_text'] = 'Sarake 2';
$lang['account_column3_text'] = 'Sarake 3';
$lang['account_column4_text'] = 'Sarake 4';
$lang['account_column5_text'] = 'Sarake 5 (vain lokikirjassa)';

$lang['account_create_user_account'] = 'Luo käyttäjätili';
$lang['account_edit_account'] = 'Muokkaa käyttäjätiliä';

$lang['account_account_information'] = 'Account Information';
$lang['account_user'] = "User";
$lang['account_word_edited'] = "edited";
$lang['account_username'] = 'käyttäjänimi';
$lang['account_email_address'] = 'Email';
$lang['account_password'] = 'Salasana';

$lang['account_roles'] = 'Roolit';
$lang['account_user_role'] = 'Käyttäjän rooli';
$lang['account_word_admin'] = 'Admin';

$lang['account_theme'] = 'Teema';
$lang['account_stylesheet'] = 'Tyylisivu';

$lang['account_personal_information'] = 'Henkilötiedot';
$lang['account_first_name'] = 'Etunimi';
$lang['account_last_name'] = 'Sukunimi';
$lang['account_callsign'] = 'Radioamatöörikutsu';
$lang['account_gridsquare'] = 'Gridsquare';

$lang['account_cloudlog_preferences'] = 'Cloudlog Asetukset';
$lang['account_timezone'] = 'Aikavyöhyke';
$lang['account_date_format'] = 'Päivämäärämuoto';
$lang['account_log_end_time'] = 'Log End Times for QSOs Separately';
$lang['account_log_end_time_hint'] = 'Choose yes here if you want to log QSO start and end times separately. If set to \'No\' the end time will be the same as start time.';
$lang['account_quicklog_feature'] = "Quicklog Field";
$lang['account_quicklog_feature_hint'] = "With this feature, you can log callsigns using the search field in the header.";
$lang['account_quicklog_enter'] = "Quicklog - Action on press Enter";
$lang['account_quicklog_enter_hint'] = "What action should be performed when Enter is pressed in the quicklog field?";
$lang['account_quicklog_enter_log'] = "Log Callsign";
$lang['account_quicklog_enter_search'] = "Search Callsign";
$lang['account_measurement_preferences'] = 'Mittayksikkömuoto';
$lang['account_select_how_you_would_like_dates_shown_when_logged_into_your_account'] = 'Valitse, miten haluat päivämäärät näkyvän, kun olet kirjautunut tilillesi.';
$lang['account_choose_which_unit_distances_will_be_shown_in'] = 'Valitse, mitä mittayksikkömuotoa käytetään';
$lang['account_cloudlog_language'] = 'Cloudlog Language';
$lang['account_choose_cloudlog_language'] = 'Choose Cloudlog language.';

$lang['account_main_menu'] = 'Menu Options';
$lang['account_show_notes_in_the_main_menu'] = 'Näytä "Muistio" päävalikossa.';

$lang['account_gridsquare_and_location_autocomplete'] = 'Gridsquare and Location Autocomplete';
$lang['account_location_auto_lookup'] = 'Location auto lookup.';
$lang['account_if_set_gridsquare_is_fetched_based_on_location_name'] = 'If set, gridsquare is fetched based on location name.';
$lang['account_sota_auto_lookup_gridsquare_and_name_for_summit'] = 'SOTA auto lookup gridsquare and name for summit.';
$lang['account_wwff_auto_lookup_gridsquare_and_name_for_reference'] = 'WWFF auto lookup gridsquare and name for reference.';
$lang['account_pota_auto_lookup_gridsquare_and_name_for_park'] = 'POTA auto lookup gridsquare and name for park.';
$lang['account_if_set_name_and_gridsquare_is_fetched_from_the_api_and_filled_in_location_and_locator'] = 'If set, name and gridsquare is fetched from the API and filled in location and locator.';

$lang['account_previous_qsl_type'] = 'Previous QSL Type';
$lang['account_select_the_type_of_qsl_to_show_in_the_previous_qsos_section'] = 'Select the type of QSL to show in the previous QSOs section.';

$lang['account_qrzcom_hamqthcom_images'] = 'qrz.com/hamqth.com Kuvat';
$lang['account_show_profile_picture_of_qso_partner_from_qrzcom_hamqthcom_profile_in_the_log_qso_section'] = 'Näytä kusokumppanin profiilikuva qrz.com/hamqth.com -profiilista lokin QSO:n kirjausikkunassa.';
$lang['account_please_set_your_qrzcom_hamqthcom_credentials_in_the_general_config_file'] = 'Anna qrz.com/hamqth.com tunnustiedot in the general config file.';

$lang['account_amsat_status_upload'] = 'AMSAT Status Upload';
$lang['account_upload_status_of_sat_qsos_to'] = 'Upload status of SAT QSOs to';

$lang['account_logbook_of_the_world'] = 'Logbook of the World';
$lang['account_logbook_of_the_world_lotw_username'] = 'Logbook of The World (LoTW) Käyttäjänimi';
$lang['account_logbook_of_the_world_lotw_password'] = 'Logbook of The World (LoTW) Salasana';
$lang['account_leave_blank_to_keep_existing_password'] = 'Jätä tyhjäksi säilyttääksesi tietokannan nykyisen salasanan';

$lang['account_clublog'] = 'Club Log';
$lang['account_clublog_email_callsign'] = 'Club Log Sähköposti/Kutsu';
$lang['account_clublog_password'] = 'Club Log Salasana';
$lang['account_the_email_or_callsign_you_use_to_login_to_club_log'] = 'Sähköposti tai kutsu, jota käytät kirjautuessasi Club Log:iin';

$lang['account_eqsl'] = 'eQSL';
$lang['account_eqslcc_username'] = 'eQSL.cc Käyttäjänimi';
$lang['account_eqslcc_password'] = 'eQSL.cc Salasana';

$lang['account_save_account_changes'] = 'Tallenna käyttäjätilin muutokset';
$lang['account_create_account'] = 'Luo käyttäjätili';

$lang['account_delete_user_account'] = 'Poista käyttäjätili';
$lang['account_are_you_sure_you_want_to_delete_the_user_account'] = 'Oletko varma, että haluat poistaa käyttäjätilin';
$lang['account_yes_delete_this_user'] = 'Kyllä, poista tämä käyttäjätili';
$lang['account_no_do_not_delete_this_user'] = 'En, älä poista tätä käyttäjätiliä';

$lang['account_forgot_password'] = 'Salasana unohtunut?';
$lang['account_you_can_reset_your_password_here'] = 'Voit resetoida salasanasi tästä';
$lang['account_reset_password'] = 'Resetoi salasana';
$lang['account_the_email_field_is_required'] = 'Sähköpostikenttä on pakollinen';
$lang['account_confirm_password'] = 'Vahvista salasana';

$lang['account_forgot_your_password'] = 'Salasana unohtunut?';

$lang['account_login_to_cloudlog'] = 'Kirjaudu Cloudlogiin';
$lang['account_login'] = 'Kirjaudu';

$lang['account_mastodon'] = 'Mastodonserver';
$lang['account_user_mastodon'] = 'URL of Mastodonserver';
$lang['account_user_mastodon_hint'] = "Main URL of your Mastodon server, e.g. <a href='https://radiosocial.de/' target='_blank'>https://radiosocial.de";

$lang['account_default_band_settings'] = 'Settings for Default Band and Confirmation';
$lang['account_gridmap_default_band'] = 'Oletusbandi';
$lang['account_qsl_settings'] = 'Default QSL-Methods';

$lang['account_winkeyer'] = 'Winkeyer';
$lang['account_winkeyer_hint'] = "Winkeyer support in Cloudlog is very experimental read the wiki first at <a href='https://github.com/magicbug/Cloudlog/wiki/Winkey' target='_blank'>https://github.com/magicbug/Cloudlog/wiki/Winkey</a> before enabling.";
$lang['account_winkeyer_enabled'] = "Winkeyer Features Enabled";
